@@ -3,10 +3,13 @@
 connection_is_open.spark_worker_connection <- function(sc) {
   bothOpen <- FALSE
   if (!identical(sc, NULL)) {
-    tryCatch({
-      bothOpen <- isOpen(sc$backend) && isOpen(sc$gateway)
-    }, error = function(e) {
-    })
+    tryCatch(
+      {
+        bothOpen <- isOpen(sc$backend) && isOpen(sc$gateway)
+      },
+      error = function(e) {
+      }
+    )
   }
   bothOpen
 }
